﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Media;

namespace RemoveUnloadOverlaySample
{
    public static class Helper
    {
        public static List<T> FindChildren<T>(FrameworkElement fe) where T : FrameworkElement
        {
            var children = new List<T>();
            var childrenCount = VisualTreeHelper.GetChildrenCount(fe);
            for (int i = 0; i < childrenCount; i++)
            {
                var child = VisualTreeHelper.GetChild(fe, i);
                Walk<T>(child as FrameworkElement, children);
            }

            return children;
        }

        private static void Walk<T>(DependencyObject fe, List<T> items) where T : FrameworkElement
        {
            var targetType = typeof(T);
            if (fe.GetType() == targetType || fe.GetType().IsSubclassOf(targetType))
            {
                items.Add((T)fe);
            }
            else
            {
                var childrenCount = VisualTreeHelper.GetChildrenCount(fe);
                for (int i = 0; i < childrenCount; i++)
                {
                    var child = VisualTreeHelper.GetChild(fe, i);
                    if (child != DependencyProperty.UnsetValue)
                    {
                        Walk<T>(child, items);
                    }
                }
            }

        }
    }
}
